Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/FCKeditor.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/FCKeditor.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/FCKeditor.java	(revision 2151)
@@ -30,6 +30,6 @@
 
 /**
- * FCKeditor class.<br />
- * It creates the html code for the FCKeditor based on the following things:
+ * Java represantation of the FCKeditor. This class creates the html code for
+ * the FCKeditor based on the following things:
  * <ul>
  * <li>browser capabilities</li>
@@ -107,9 +107,9 @@
 	 * Set the unique name of the editor
 	 * 
-	 * @param value
+	 * @param instanceName
 	 *            name
 	 */
-	public void setInstanceName(final String value) {
-		instanceName = value;
+	public void setInstanceName(final String instanceName) {
+		this.instanceName = instanceName;
 	}
 
@@ -129,9 +129,9 @@
 	 * path from the context (e.g. /fckeditor).
 	 * 
-	 * @param value
+	 * @param basePath
 	 *            path
 	 */
-	public void setBasePath(final String value) {
-		basePath = value;
+	public void setBasePath(final String basePath) {
+		this.basePath = basePath;
 	}
 
@@ -139,9 +139,9 @@
 	 * Set the name of the toolbar to display
 	 * 
-	 * @param value
+	 * @param toolbarSet
 	 *            toolbar name
 	 */
-	public void setToolbarSet(final String value) {
-		toolbarSet = value;
+	public void setToolbarSet(final String toolbarSet) {
+		this.toolbarSet = toolbarSet;
 	}
 
@@ -149,9 +149,9 @@
 	 * Set the width of the textarea
 	 * 
-	 * @param value
+	 * @param width
 	 *            width
 	 */
-	public void setWidth(final String value) {
-		width = value;
+	public void setWidth(final String width) {
+		this.width = width;
 	}
 
@@ -159,9 +159,9 @@
 	 * Set the height of the textarea
 	 * 
-	 * @param value
+	 * @param height
 	 *            height
 	 */
-	public void setHeight(final String value) {
-		height = value;
+	public void setHeight(final String height) {
+		this.height = height;
 	}
 
@@ -176,44 +176,45 @@
 		return config;
 	}
-
-	/**
-	 * Set the advanced configuration set.
-	 * 
-	 * @param value
+	/**
+	 * Set the advanced configuation set.
+	 * 
+	 * @param config
 	 *            configuration collection
 	 */
-	public void setConfig(FCKeditorConfig value) {
-		config = value;
+	public void setConfig(FCKeditorConfig config) {
+		this.config = config;
 	}
 
 	/**
 	 * Escape base XML entities as specified <a
-	 * href="http://en.wikipedia.org/wiki/Xml#Entity_references">here</a>
-	 * 
-	 * @param txt
+	 * href="http://en.wikipedia.org/wiki/Xml#Entity_references">here</a>.
+	 * 
+	 * @param str
 	 *            Text to escape.
 	 * @return Escaped text.
 	 */
-	private String escapeXml(String txt) {
-		if (Utils.isEmpty(txt))
-			return txt;
-		txt = txt.replaceAll("&", "&#38;");
-		txt = txt.replaceAll("<", "&#60;");
-		txt = txt.replaceAll(">", "&#62;");
-		txt = txt.replaceAll("\"", "&#34;");
-		txt = txt.replaceAll("'", "&#39;");
-		return txt;
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * @see #createHtml()
-	 */
-	public String create() {
-		return createHtml();
+	private String escapeXml(String str) {
+		if (Utils.isEmpty(str))
+			return str;
+		
+		/*
+		 * TODO Strings are inefficent. It should be done like in Commons Lang
+		 * 2.4 StringUtils#replaceEach(String, String[], String[])
+		 */
+		str = str.replaceAll("&", "&#38;");
+		str = str.replaceAll("<", "&#60;");
+		str = str.replaceAll(">", "&#62;");
+		str = str.replaceAll("\"", "&#34;");
+		str = str.replaceAll("'", "&#39;");
+		return str;
 	}
 	
 	/*
 	 * (non-Javadoc)
+	 * 
+	 * @see #createHtml()
+	 */
+	/**
+	 * This method simply wraps to {@link #createHtml()}.
 	 * @see #createHtml()
 	 */
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/FCKeditorConfig.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/FCKeditorConfig.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/FCKeditorConfig.java	(revision 2151)
@@ -33,5 +33,5 @@
 
 /**
- * Contains the configuration settings for the FCKEditor.<br>
+ * Contains the configuration settings for the FCKeditor.<br />
  * By adding elements to this collection you can override the settings specified
  * in the config.js file.
@@ -47,5 +47,5 @@
 	 * Initialize the configuration collection
 	 */
-	public FCKeditorConfig() {
+	public FCKeditorConfig(	) {
 		super();
 	}
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/RequestCycleHandler.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/RequestCycleHandler.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/RequestCycleHandler.java	(revision 2151)
@@ -51,5 +51,5 @@
 				Class<?> clazz = Class.forName(fqcn);
 				userAction = (UserAction) clazz.newInstance();
-				logger.info("UserAction object successfully instantiated!");
+				logger.info("UserAction implementation successfully instantiated!");
 			} catch (Exception e) {
 				logger.error("Couldn't instantiate class [".concat(fqcn).concat(
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/ResourceTypeHandler.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/ResourceTypeHandler.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/ResourceTypeHandler.java	(revision 2151)
@@ -23,4 +23,6 @@
 import java.util.HashMap;
 import java.util.Map;
+
+import net.fckeditor.tool.Utils;
 
 /**
@@ -85,8 +87,8 @@
 	 *         represented by the string argument.
 	 * @throws IllegalArgumentException
-	 *             If 'name' is null can't be parsed.
+	 *            If 'name' is <code>null</code>, empty, or does not exist.
 	 */
 	public static ResourceTypeHandler valueOf(final String name) throws IllegalArgumentException {
-		if (name == null)
+		if (Utils.isEmpty(name))
 			throw new IllegalArgumentException();
 
@@ -110,4 +112,11 @@
 	}
 
+	/**
+	 * Tries to determine ResourceType from string and return {@link #FILE} if
+	 * provided string is invalid.
+	 * 
+	 * @param name
+	 * @return resource type
+	 */
 	public static ResourceTypeHandler getDefaultResourceType(final String name) {
 		ResourceTypeHandler rt = getResourceType(name);
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/UserAction.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/UserAction.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/UserAction.java	(revision 2151)
@@ -25,6 +25,6 @@
 
 /**
- * Interface that provides the authorization of the following file based user
- * actions:
+ * An interface which provides the authorization of server-side commands.<br />
+ * The commands are:
  * <ul>
  * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/UserPathBuilder.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/UserPathBuilder.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/UserPathBuilder.java	(revision 2151)
@@ -26,5 +26,5 @@
 
 /**
- * Interface to provide a way to build a user-dependent
+ * An interface which provides a way to build a user-dependent
  * <code>UserFilesPath</code>.
  * 
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserActionImpl.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserActionImpl.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserActionImpl.java	(revision 2151)
@@ -26,6 +26,7 @@
 
 /**
- * Standard implementation for {@link UserAction}.
- *
+ * Standard implementation for {@link UserAction}. It always returns
+ * <code>true</code>.
+ * 
  * @version $Id$
  */
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java	(revision 2151)
@@ -25,5 +25,5 @@
 
 /**
- * Simply abstracts from the javascript callback to a java class.
+ * Simply abstracts from the JavaScript callback to a Java object.
  * 
  * <p>
@@ -108,5 +108,5 @@
 
 	/**
-	 * Sets the message in the UploadResponse.
+	 * Sets the message in the <code>UploadResponse</code>.
 	 * 
 	 * Methods automatically determines how many arguments are set and puts the
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/XmlResponse.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/XmlResponse.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/XmlResponse.java	(revision 2151)
@@ -44,10 +44,10 @@
 
 /**
- * static error objects won't probably provided due to performance reasons of 
- * Document instance creation
- * 
- * TODO document me!
- * @author mosipov
- *
+ * Creates an XML response for every <code>GET</code> request of the Connector
+ * servlet. This class maps directly to the XML layout descibed <a
+ * href="http://docs.fckeditor.net/FCKeditor_2.x/Developers_Guide/Server_Side_Integration#The_Commands">here</a>.
+ * 
+ * @version $Id$
+ * 
  */
 public class XmlResponse {
@@ -77,4 +77,5 @@
 
 	/**
+	 * Use this contructor if want to respond a positive message.
 	 * 
 	 * @param command
@@ -109,5 +110,8 @@
 	
 	/**
-	 * TODO document me!
+	 * 
+	 * Use this contructor if want to respond a negative/error message with
+	 * custom text.
+	 * 
 	 * @param number
 	 * @param text
@@ -128,6 +132,7 @@
 	}
 	
-	/***
-	 * TODO document me!
+	/**
+	 * Use this contructor if want to respond a negative/error message only.
+	 * 
 	 * @param number
 	 */
@@ -136,4 +141,10 @@
 	}
 
+	/**
+	 * Sets an error number with a custom message.
+	 * 
+	 * @param number
+	 * @param text
+	 */
 	public void setError(int number, String text) {
 
@@ -149,8 +160,17 @@
 	}
 
+	/**
+	 * Sets an error number.
+	 * 
+	 * @param number
+	 */
 	public void setError(int number) {
 		setError(number, null);
 	}
 
+	/**
+	 * Lists all folders in the given dir as XML tags.
+	 * @param dir
+	 */
 	public void setFolders(File dir) {
 
@@ -171,4 +191,9 @@
 	}
 	
+	/**
+	 * Lists all files in the given dir as XML tags.
+	 * 
+	 * @param dir
+	 */
 	public void setFiles(File dir) {
 		
@@ -195,4 +220,9 @@
 	}
 	
+	/**
+	 * Lists all folders and files in the given dir as XML tags.
+	 * 
+	 * @param dir
+	 */	
 	public void setFoldersAndFiles(File dir) {
 		setFolders(dir);
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 2151)
@@ -36,6 +36,9 @@
 
 /**
- * CheckTag.java - TODO DOCUMENTME!
- *
+ * This tag displays information about browser and user capabilities. There are
+ * tree available commands (CompatibleBrowser, FileBrowsing, FileUpload) which
+ * respond an English message.<br />
+ * <strong>Hint</strong>: The message string cannot be localized at the moment.
+ * 
  * @version $Id$
  */
@@ -63,4 +66,9 @@
 	private String command;
 
+	/**
+	 * Sets the desired command.
+	 * @param command
+	 * @throws JspTagException
+	 */
 	public void setCommand(String command) throws JspTagException {
 		if (!commands.contains(command))
@@ -106,6 +114,5 @@
 			out.print(response);
 		} catch (IOException e) {
-			// FIXME log or else
-			e.printStackTrace();
+			throw new JspException("Tag response could not be written to the user!",e);
 		}
 
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/ConfigTag.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/ConfigTag.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/ConfigTag.java	(revision 2151)
@@ -30,6 +30,11 @@
 
 /**
- * ConfigTag.java - TODO DOCUMENTME!
- *
+ * This tag sets configuration options for the surrounding editor tag. Provide
+ * any configuraion options you want as described <a
+ * href="http://docs.fckeditor.net/FCKeditor_2.x/Developers_Guide/Configuration/Configuration_Options">here</a>.
+ * This tag utilizes the dynamic attribute features provided by the
+ * {@link DynamicAttributes} interface.<br />
+ * <strong>Attention</strong>: This tag can only be nested with an editor tag.
+ * 
  * @version $Id$
  */
@@ -37,5 +42,5 @@
 
 	private Map<String, String> params = new HashMap<String, String>();
-	
+
 	private static final long serialVersionUID = -5282810094404700422L;
 
@@ -49,13 +54,15 @@
 		EditorTag editorTag = (EditorTag) ancestor;
 		editorTag.setConfigParamAll(params);
-		
+
 		return SKIP_BODY;
 	}
 
-	public void setDynamicAttribute(String arg0, String arg1, Object arg2)
+	/**
+	 * Sets the desired FCKeditor configuration option.
+	 */
+	public void setDynamicAttribute(String arg0, String name, Object value)
 			throws JspException {
-		// TODO shall we check arg1 too?
-		if (arg2 != null)
-			params.put(arg1, arg2.toString());
+		if (value != null)
+			params.put(name, value.toString());
 	}
 
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/EditorTag.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/EditorTag.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/EditorTag.java	(revision 2151)
@@ -33,43 +33,6 @@
 
 /**
- * TODO revise this documentation
  * FCKeditor Tag class to access the
- * {@linkplain net.fckeditor.FCKeditor container}.<br />
- * <p>
- * <b>Simple usage</b>:
- * 
- * <pre>
- * &lt;FCK:editor instanceName=&quot;EditorAccessibility&quot; width=&quot;80%&quot;
- *    height=&quot;120&quot; toolbarSet=&quot;Accessibility&quot;&gt;
- *    &lt;jsp:attribute name=&quot;value&quot;&gt;
- *      This is another test.&lt;br/&gt;The &quot;second&quot; row.
- *    &lt;/jsp:attribute&gt;
- * &lt;/FCK:editor&gt;
- * </pre>
- * 
- * </p>
- * 
- * In this example we set all the attribute for the FCKeditor tag.
- * 
- * <p>
- * <b>Advanced usage of the tag</b>:
- * 
- * <pre>
- * &lt;FCK:editor instanceName=&quot;EditorDefault&quot; basePath=&quot;/fckeditor/&quot;&gt;
- *   &lt;jsp:attribute name=&quot;value&quot;&gt;
- *     This is another test.&lt;br/&gt;The &quot;second&quot; row.
- *   &lt;/jsp:attribute&gt;
- *   &lt;jsp:body&gt;
- *     &lt;FCK:config IndentUnit=&quot;cm&quot; FontNames=&quot;Arial;Courier New;Times New Roman;Verdana&quot; /&gt;
- *   &lt;/jsp:body&gt;
- * &lt;/FCK:editor&gt;
- * </pre>
- * 
- * In this example we set the instanceName and the basePath of the editor (since
- * it is /fckeditor/ we could have omitted it because it's already the default
- * value).<br />
- * Then we used the the optional attributes to set some advanced configuration
- * settings.
- * </p>
+ * {@linkplain net.fckeditor.FCKeditor container}.
  * 
  * @version $Id$
@@ -163,5 +126,4 @@
 				(HttpServletRequest) pageContext.getRequest(), instanceName,
 				width, height, toolbarSet, value, basePath);
-		fckEditor.setValue(value);
 
 		return EVAL_BODY_INCLUDE;
@@ -175,8 +137,6 @@
 		try {
 			out.println(fckEditor);
-		} catch (IOException ioe) {
-			// TODO improve exception message
-			throw new JspException(
-					"Error: IOException while writing to the user");
+		} catch (IOException e) {
+			throw new JspException("Tag response could not be written to the user!",e);
 		}
 
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Utils.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Utils.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/Utils.java	(revision 2151)
@@ -65,6 +65,6 @@
 	 * delimiter.
 	 */
-	public static Set<String> getSet(final String stringlist) {
-		return getSet(stringlist, "|");
+	public static Set<String> getSet(final String stringList) {
+		return getSet(stringList, "|");
 	}
 
@@ -90,37 +90,3 @@
 		return !isEmpty(str);
 	}
-
-	/**
-	 * Replaces all 'search' with 'replacement' in 'string'.<br />
-	 * Usage:
-	 * 
-	 * <pre>
-	 * Utils.replaceAll(null, *, *)		= &quot;&quot;
-	 * Utils.replaceAll(&quot;&quot;, *, *)		= &quot;&quot;
-	 * Utils.replaceAll(&quot;foo&quot;, null, *)	= &quot;foo&quot;
-	 * Utils.replaceAll(&quot;foo&quot;, &quot;o&quot;, &quot;a&quot;)	= &quot;faa&quot;
-	 * </pre>
-	 * 
-	 * @param string
-	 * @param search
-	 * @param replacement
-	 * @return replaced String
-	 */
-	public static String replaceAll(final String string, final String search,
-			final String replacement) {
-		if (isEmpty(string))
-			return "";
-		if (isEmpty(search))
-			return string;
-		if (string.indexOf(search) == -1)
-			return string;
-		StringBuffer sb = new StringBuffer(string);
-		int pos = sb.indexOf(search);
-
-		while (pos != -1) {
-			sb.replace(pos, pos + search.length(), replacement);
-			pos = sb.indexOf(search);
-		}
-		return sb.toString();
-	}
 }
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java	(revision 2151)
@@ -94,10 +94,11 @@
 
 	/**
-     * Checks, if <code>path</code> is a valid one. 
-     * 
-     * @param path
-     * @return <code>true</code> if path corresponds to rules or
-     *         <code>false</code>.
-     */
+	 * Checks if a path corresponds to the rules defined <a
+	 * href="http://docs.fckeditor.net/FCKeditor_2.x/Developers_Guide/Server_Side_Integration#File_Browser_Requests">here</a>.
+	 * 
+	 * @param path
+	 * @return <code>true</code> if path corresponds to rules or
+	 *         <code>false</code>.
+	 */
     public static boolean isValidPath(final String path) {
     	if (Utils.isEmpty(path))
@@ -116,10 +117,9 @@
 
 	/**
-     * Makes sure that <code>filename</code> has only one extension.
-     * Other dots will be replaced with '_'.
-     * 
-     * @param filename
-     * @return String with a single extension only.
-     */
+	 * Replaces all dots except the last one with underscores in a filename.
+	 * 
+	 * @param filename
+	 * @return string with a single dot only
+	 */
     public static String forceSingleExtension(final String filename) {
     	return filename.replaceAll("\\.(?![^.]+$)", "_");
@@ -127,9 +127,9 @@
 
 	/**
-     * Checks, if <code>filename</code> has a single extension.
+     * Checks if a filename contains more than one dot.
      * 
      * @param filename
-     * @return <code>true</code> if filename has just one dot, else
-     *         <code>false</code>.
+     * @return <code>true</code> if filename contains severals dots else
+     *         <code>false</code>
      */
     public static boolean isSingleExtension(final String filename) {
@@ -138,9 +138,9 @@
     
     /**
-	 * Checks if <code>dir</code> exists, if not it will be created.
+	 * Checks for a dir and creates it if it does not exist.
 	 * 
 	 * @param dir Directory to check/create.
 	 */
-	public static void checkDirAndCreate(final File dir) {
+	public static void checkDirAndCreate(File dir) {
 		if (!dir.exists()) {
 			dir.mkdirs();
@@ -150,6 +150,5 @@
 	
 	/**
-	 * Constructs the server-side path for a special <code>resourceType</code>. 
-	 * Path is inside the <code>UserFilePath</code>.
+	 * Compose server-side response path.
 	 * 
 	 * @param request
@@ -157,6 +156,6 @@
 	 * @return server-side path of <code>resourceType</code>.
 	 */
-	public static String constructServerSidePath(final HttpServletRequest request,
-			final ResourceTypeHandler resourceType) {
+	public static String constructServerSidePath(HttpServletRequest request,
+			ResourceTypeHandler resourceType) {
 		StringBuffer sb = new StringBuffer(ConnectorHandler
 				.getUserFilesPath(request));
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java	(revision 2151)
@@ -23,5 +23,4 @@
 import javax.servlet.http.HttpServletRequest;
 
-import net.fckeditor.connector.ConnectorServlet;
 import net.fckeditor.handlers.ConnectorHandler;
 import net.fckeditor.handlers.ResourceTypeHandler;
@@ -35,13 +34,14 @@
 
 	/**
-	 * Constructs an url, using as response in {@link ConnectorServlet}.
-     * 
-     * @param request
-     * @param resourceType
-     * @param urlPath
-     * @param prependContextPath
-     * @param fullUrl
-     * @return constructed url
-     */
+	 * Constructs a URL from different parameters. This method is about to
+	 * change in version 2.5.
+	 * 
+	 * @param request
+	 * @param resourceType
+	 * @param urlPath
+	 * @param prependContextPath
+	 * @param fullUrl
+	 * @return constructed url
+	 */
     public static String constructResponseUrl(HttpServletRequest request,
     		ResourceTypeHandler resourceType, String urlPath,
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/XHtmlTagTool.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/XHtmlTagTool.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/XHtmlTagTool.java	(revision 2151)
@@ -25,5 +25,5 @@
 
 /**
- * Tool to construct a XHTML-tag.<br>
+ * Tool to construct a XHTML tag.<br>
  * <br>
  * Usage:
@@ -80,12 +80,12 @@
 	 * Adds an attribute to the tag.
 	 * 
-	 * @param key
+	 * @param name
 	 * @param value
 	 * @throws IllegalArgumentException if 'key' is empty.
 	 */
-	public void addAttribute(final String key, final String value) {
-		if (Utils.isEmpty(key))
-			throw new IllegalArgumentException("Parameter 'key' shouldn't be empty!");
-		attributes.put(key, value);
+	public void addAttribute(final String name, final String value) {
+		if (Utils.isEmpty(name))
+			throw new IllegalArgumentException("Parameter 'name' shouldn't be empty!");
+		attributes.put(name, value);
 	}
 
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/connector/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/connector/package.html	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/connector/package.html	(revision 2151)
@@ -27,42 +27,10 @@
 Connector used by the FCKeditor to list and create resources on the server.
 
-<h2>Package Specification</h2>
-
-This servlet is access directly from the file browser in the FCKeditor.<br>
-To make everything work correctly you have to add the following piece of code in your application's web.xml
-<br>
-<pre>
-	&lt;servlet&gt;
-		&lt;servlet-name&gt;Connector&lt;/servlet-name&gt;
-		&lt;servlet-class&gt;net.fckeditor.connector.ConnectorServlet&lt;/servlet-class&gt;
-		&lt;init-param&gt;
-			&lt;param-name&gt;baseDir&lt;/param-name&gt;
-			&lt;param-value&gt;/UserFiles/&lt;/param-value&gt;
-		&lt;/init-param&gt;
-		&lt;init-param&gt;
-			&lt;param-name&gt;debug&lt;/param-name&gt;
-			&lt;param-value&gt;false&lt;/param-value&gt;
-		&lt;/init-param&gt;
-		&lt;load-on-startup&gt;1&lt;/load-on-startup&gt;
-	&lt;/servlet&gt;
-
-	&lt;servlet-mapping&gt;
-		&lt;servlet-name&gt;Connector&lt;/servlet-name&gt;
-		&lt;url-pattern&gt;/editor/filemanager/browser/default/connectors/jsp/connector&lt;/url-pattern&gt;
-	&lt;/servlet-mapping&gt;
-</pre>
-<br>
-And put in the fckconfig.js the following line:
-<pre>
-FCKConfig.LinkBrowserURL = FCKConfig.BasePath + "filemanager/browser/default/browser.html?Connector=connectors/jsp/connector" ;
-FCKConfig.ImageBrowserURL = FCKConfig.BasePath + "filemanager/browser/default/browser.html?Type=Image&Connector=connectors/jsp/connector" ;
-FCKConfig.FlashBrowserURL = FCKConfig.BasePath + "filemanager/browser/default/browser.html?Type=Flash&Connector=connectors/jsp/connector" ;
-</pre>
-Also, since the servlet manage a file upload using the Jakarta Common fileupload library, you need to put in your <code>WEB-INF/lib/</code> the <code>commons-fileupload.jar</code>.
 <h2>Related Documentation</h2>
 
 For overviews, tutorials, examples, guides, and tool documentation, please see:
 <ul>
-  <li>_sample/jsp directory for example of how to implement FCKeditor in your application
+  <li>The official FCKeditor.Java integration <a href="http://java.fckeditor.net">website</a>.
+  <li>The example web application. 
 </ul>
 
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/package.html	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/package.html	(revision 2151)
@@ -19,5 +19,4 @@
  * == END LICENSE ==
 -->
-
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
 <html>
@@ -27,5 +26,4 @@
 
 Core objects to manage the FCKeditor text input form.
-Java Integration Module 2.4.
 
 <h2>Related Documentation</h2>
@@ -33,5 +31,5 @@
 For overviews, tutorials, examples, guides, and tool documentation, please see:
 <ul>
-  <li><a href="http://www.fckeditor.net/">Official web site of FCKeditor</a>
+  <li><a href="http://docs.fckeditor.net/">Official documenation of the FCKeditor</a>.
 </ul>
 
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/requestcycle/impl/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/requestcycle/impl/package.html	(revision 2151)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/requestcycle/impl/package.html	(revision 2151)
@@ -0,0 +1,96 @@
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Basic/pre-defined implementations for the request cycle interfaces.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Basic/pre-defined implementations for the request cycle interfaces.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Basic/pre-defined implementations for the request cycle interfaces.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/requestcycle/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/requestcycle/package.html	(revision 2151)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/requestcycle/package.html	(revision 2151)
@@ -0,0 +1,96 @@
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Interfaces for the request life cycle.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Interfaces for the request life cycle.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Interfaces for the request life cycle.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/response/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/response/package.html	(revision 2151)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/response/package.html	(revision 2151)
@@ -0,0 +1,96 @@
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Response object wrappers for <code>GET</code> and <code>POST</code> requests.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Response object wrappers for <code>GET</code> and <code>POST</code> requests.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Response object wrappers for <code>GET</code> and <code>POST</code> requests.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/tags/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/tags/package.html	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/tags/package.html	(revision 2151)
@@ -25,15 +25,5 @@
 <body bgcolor="white">
 
-JSP Tag to access and modify the FCKeditor objects.
-
-
-<h2>Package Specification</h2>
-
-This taglibrary is compliant to the taglib 1.1 specification.<br>
-To use it put the FCKeditor.jar inside the <code>WEB-INF/lib</code> dir and FCKeditor.tld inside the <code>WEB-INF</code> directory of your website.<br>
-Put the following declaration in each page that use the tags:<br>
-<pre>
-&lt;%@ taglib uri="http://fckeditor.net/tags-fckeditor" prefix="FCK" %&gt;
-</pre>
+JSP tags to access and modify the FCKeditor object.
 
 <h2>Related Documentation</h2>
@@ -41,5 +31,6 @@
 For overviews, tutorials, examples, guides, and tool documentation, please see:
 <ul>
-  <li>_sample/jsp directory for example of how to implement FCKeditor in your application
+  <li>The official FCKeditor.Java integration <a href="http://java.fckeditor.net">website</a>.
+  <li>The example web application. 
 </ul>
 
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/tool/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/tool/package.html	(revision 2151)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/net/fckeditor/tool/package.html	(revision 2151)
@@ -0,0 +1,96 @@
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Various tool classes.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Various tool classes.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+Various tool classes.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
Index: FCKeditor.Java/trunk/java-core/src/main/javadoc/org/devlib/schmidt/imageinfo/package.html
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/javadoc/org/devlib/schmidt/imageinfo/package.html	(revision 2151)
+++ FCKeditor.Java/trunk/java-core/src/main/javadoc/org/devlib/schmidt/imageinfo/package.html	(revision 2151)
@@ -0,0 +1,102 @@
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+External image information application. See
+<a href="ImageInfo.html">ImageInfo</a>
+for more information.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+External image information application. See
+<a href="ImageInfo.html">ImageInfo</a>
+for more information.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
+<!--
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+-->
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
+<html>
+<head>
+</head>
+<body bgcolor="white">
+
+External image information application. See
+<a href="ImageInfo.html">ImageInfo</a>
+for more information.
+
+<!-- Put @see and @since tags down here. -->
+
+</body>
+</html>
Index: FCKeditor.Java/trunk/java-core/src/test/java/net/fckeditor/tool/UtilsTest.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/test/java/net/fckeditor/tool/UtilsTest.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/test/java/net/fckeditor/tool/UtilsTest.java	(revision 2151)
@@ -21,7 +21,5 @@
 package net.fckeditor.tool;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-
+import static org.junit.Assert.*;
 import java.util.HashSet;
 import java.util.Set;
@@ -61,5 +59,5 @@
 		}
 	}
-	
+
 	@Test
 	public void getSet03() {
@@ -76,26 +74,3 @@
 	}
 
-	@Test
-	public void replaceAll01() {
-		String str = Utils.replaceAll("//a/b//c", "//", "/");
-		assertEquals(str, "/a/b/c");
-	}
-
-	@Test
-	public void replaceAll02() {
-		String str = Utils.replaceAll(null, "a", "c");
-		assertEquals(str, "");
-	}
-
-	@Test
-	public void replaceAll03() {
-		String str = Utils.replaceAll("foo", null, "c");
-		assertEquals(str, "foo");
-	}
-
-	@Test
-	public void replaceAll04() {
-		String str = Utils.replaceAll("foo", "o", "a");
-		assertEquals(str, "faa");
-	}
 }
Index: FCKeditor.Java/trunk/src/site/apt/connector.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/connector.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/connector.apt	(revision 2151)
@@ -24,5 +24,5 @@
 Connector activation
 
-  The Connector is not mandatory. If you do <not> plan to provide userfile
+  The Connector is not mandatory. If you do <not> plan to provide file
   interaction, you can skip this section.
 
@@ -34,5 +34,5 @@
   [[1]]  Declare the ConnectorServlet in your <<<web.xml>>>
 
-+--------------------------------------------------+
++------------------------------------------------------------------------------+
   <web-app version="2.4">
     ...
@@ -53,5 +53,5 @@
     ...
   </web-app>
-+--------------------------------------------------+
++------------------------------------------------------------------------------+
 
   Assuming you installed the editor in the <<</fckeditor>>> folder in your webapp.\
@@ -61,7 +61,7 @@
   [[2]] Create a <<<fckeditor.properties>>> file in your classpath and add:
 
-+------------------------------------------------------------------------+
++------------------------------------------------------------------------------+
   connector.userActionImpl=net.fckeditor.requestcycle.impl.UserActionImpl
-+------------------------------------------------------------------------+
++------------------------------------------------------------------------------+
 
   []
@@ -74,14 +74,14 @@
              Connector.
 
-  The basic idea of extending the Connector is to provide interfaces for user-dependent
-  interactions which can be implemented by the web application developer. All
-  methods are passed the current <<<HttpServletRequest>>> instance in order to
-  retrieve request and/or session attributes to assemble a user-specific
+  The basic idea of extending the Connector is to provide interfaces for
+  user-dependent interactions which can be implemented by the web application
+  developer. All methods are passed the current <<<HttpServletRequest>>> instance
+  in order to retrieve request and/or session attributes to assemble a user-specific
   return value. We intentionally do not impose any constraints or indorse any
   particular implementation approach to give you the freedom to implement the
   interfaces the way it fits best in your environment.
 
-  Supply the fully-qualified class names of the implemented classes as described in
-  the {{{properties.html}Configuration settings}}.
+  Supply the fully-qualified class names of the implemented classes as described
+  in the {{{properties.html}fonfiguration settings}}.
 
   Right now, the integration pack provides two interfaces to extend the Connector:
@@ -89,7 +89,7 @@
   [[1]] {{{java-core/apidocs/net/fckeditor/requestcycle/UserPathBuilder.html}<<<net.fckeditor.requestcycle.UserPathBuilder>>>}}
 
-        This interface consists only of one method <<<#getUserFilesPath(final HttpServletRequest)>>>
-        which returns a string. You are able to construct a user-dependent 
-        <<<UserFilesPath>>>, e.g. <<</userfiles/johndoe>>>.
+        This interface consists only of one method <<<String getUserFilesPath(final HttpServletRequest)>>>.
+        You are able to construct a user-dependent <<<UserFilesPath>>>, e.g.
+        <<</userfiles/johndoe>>>.
 
   [[2]] {{{java-core/apidocs/net/fckeditor/requestcycle/UserAction.html}<<<net.fckeditor.requestcycle.UserAction>>>}}
@@ -97,9 +97,9 @@
         There are two methods to authorize users to do file-based actions:
 
-        * <<<#isEnabledForFileBrowsing(HttpServletRequest)>>> which returns a 
-          <<<boolean>>> denoting the user's ability to browse files on the server.
+        * <<<boolean isEnabledForFileBrowsing(final HttpServletRequest)>>> denoting
+          the user's ability to browse files on the server.
   
-        * <<<#isEnabledForFileUpload(HttpServletRequest)>>> which returns a 
-          <<<boolean>>> denoting the user's ability to upload files to the server.
+        * <<<boolean isEnabledForFileUpload(final HttpServletRequest)>>> denoting
+          the user's ability to upload files to the server.
 
         []
Index: FCKeditor.Java/trunk/src/site/apt/demo.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/demo.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/demo.apt	(revision 2151)
@@ -27,17 +27,17 @@
                     server implementation to run the library and the demo webapp.
 
-  The demo is intended for novices, beginners and for everyone who wants to see
-  the FCKeditor (version 2.6) in action right out of the box. It's also a good 
+  The demo is intended for novices, beginners, and for everyone who wants to see
+  the FCKeditor (version 2.6.2) in action right out of the box. It's also a good 
   reference for you to see how all integral parts work together.
 
   It takes three simple steps to see the demo in action:
 
-   [[1]] Download the <<<fckeditor-java-demo-2.4-beta-1.war>>> from the
+   [[1]] Download the <<<fckeditor-java-demo-2.4.war>>> from the
          {{{http://sourceforge.net/project/showfiles.php?group_id=75348&package_id=129511}download area}}.
 
-   [[2]] Deploy the <<<fckeditor-java-demo-2.4-beta-1.war>>> in your servlet container 
+   [[2]] Deploy the <<<fckeditor-java-demo-2.4.war>>> in your servlet container 
          or application server and make sure that the context is enabled.
         
-   [[3]] Open up your browser and point to <<<http://localhost:8080/fckeditor-java-demo-2.4-beta-1>>>.
+   [[3]] Open up your browser and point to <<<http://localhost:8080/fckeditor-java-demo-2.4>>>.
          (assuming your server is running local at port 8080 for testing purposes)
 
Index: FCKeditor.Java/trunk/src/site/apt/index.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/index.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/index.apt	(revision 2151)
@@ -32,5 +32,5 @@
   Although it's targeted to be used as a tag library within JSPs, it's a snap
   within a template engine like {{{http://velocity.apache.org}Velocity}} or 
-  {{{http://freemarker.org}Freemarker}} too.
+  {{{http://freemarker.org}FreeMarker}} too.
 
 * Documentation Guideline
Index: FCKeditor.Java/trunk/src/site/apt/installation.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/installation.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/installation.apt	(revision 2151)
@@ -32,24 +32,24 @@
   your POM:
 
-+-------------------------------------------------------+
++------------------------------------------------------------------------------+
 <dependency>
   <groupId>net.fckeditor</groupId>
   <artifactId>java-core</artifactId>
-  <version>2.4-beta-1</version>
+  <version>2.4</version>
 </dependency>
-+-------------------------------------------------------+
++------------------------------------------------------------------------------+
 
 * Manual installation
 
   The distribution comes in three flavors, pick one from the 
-  {{{http://sourceforge.net/project/showfiles.php?group_id=75348&package_id=129511}download area}} which fits best in your
-  environment.
+  {{{http://sourceforge.net/project/showfiles.php?group_id=75348&package_id=129511}download area}}
+  which fits best in your environment.
 
-  * <<<fckeditor-java-core-2.4-beta-1.jar>>>
+  * <<<fckeditor-java-core-2.4.jar>>>
 
     If you already have all dependencies on your classpath, simply put this jar
     on your classpath (usually <<<WEB-INF/lib>>>) and you are ready to go.
 
-  * <<<fckeditor-java-2.4-beta-1-bin.zip>>> (or <<<tar.gz>>>)
+  * <<<fckeditor-java-2.4-bin.zip>>> (or <<<tar.gz>>>)
 
     If you are starting from scratch, this distribution fits best. This package
@@ -62,7 +62,7 @@
 || File                                      || Description                    ||
 *--------------------------------------------+----------------------------------+
-| fckeditor-java-core-2.4-beta-1.jar         | main jar                         |
+| fckeditor-java-core-2.4.jar                | main jar                         |
 *--------------------------------------------+----------------------------------+
-| fckeditor-java-core-2.4-beta-1-javadoc.jar | optional javadoc for IDE integration |
+| fckeditor-java-core-2.4-javadoc.jar        | optional javadoc for IDE integration |
 *--------------------------------------------+----------------------------------+
 
@@ -76,5 +76,5 @@
 | commons-io-1.3.2.jar                       | Apache Commons IO library        |
 *--------------------------------------------+----------------------------------+
-| slf4j-api-1.5.0.jar                        | Simple logging facade library    |
+| slf4j-api-1.5.2.jar                        | Simple logging facade library    |
 *--------------------------------------------+----------------------------------+
 
@@ -82,5 +82,5 @@
     <<<WEB-INF/lib>>>) and you are ready to go.
 
-  * <<<fckeditor-java-2.4-beta-1-src.zip>>>  (or <<<tar.gz>>>)
+  * <<<fckeditor-java-2.4-src.zip>>>  (or <<<tar.gz>>>)
 
     If you want to check out the integration's source code, refit to your needs
@@ -94,11 +94,12 @@
   Although the public distribution is fine, it still contains a lot of superfluous
   files for a Java environment. Use the following <<<Ant>>> target on the FCKeditor
-  zip file (1,25 MiB) to create a cleaner and smaller distribution zip file (986 KiB).
+  zip file (~1,25 MiB) to create a cleaner and smaller distribution zip file
+  (~986 KiB).
 
-+----------------------------------------------------------------------------------+
++------------------------------------------------------------------------------+
 <target name="clean-fckeditor" description="Creates a clean FCKeditor distribution">
   <!-- Adapt properties to your needs -->
   <property name="fckeditor-tmp" location="fckeditor-tmp" />
-  <property name="fckeditor-basename" value="FCKeditor_2.6" />
+  <property name="fckeditor-basename" value="FCKeditor_2.6.2" />
   <property name="fckeditor-destfile" value="${fckeditor-basename}_clean.zip" />
 
@@ -116,5 +117,5 @@
   <delete dir="${fckeditor-tmp}" />
 </target>
-+----------------------------------------------------------------------------------+
++------------------------------------------------------------------------------+
 
 A word on Logging
@@ -122,7 +123,7 @@
     [Attention:] Do <not> skip this section otherwise your application will <<fail>>!
 
-  We use the state-of-the-art logging facade <<<SLF4J>>>. To make SFL4J work at runtime, 
-  you have to add <<one>> binding and the appropriate  backend (may be optional) into 
-  your classpath.\
-  Please check the {{{http://slf4j.org}SLF4J website}} for more information on bindings
-  and the API itself.
+  We use the state-of-the-art logging facade <<<SLF4J>>>. To make SFL4J work at
+  runtime, you have to add <<one>> binding and the appropriate backend (may
+  be optional) into your classpath.\
+  Please check the {{{http://slf4j.org}SLF4J website}} for more information on
+  bindings and the API itself.
Index: FCKeditor.Java/trunk/src/site/apt/overview.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/overview.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/overview.apt	(revision 2151)
@@ -28,5 +28,6 @@
   * <<JSP tag library>>: Easy integration of the FCKeditor in your JSPs.
     
-  * <<Connector>>: A servlet to manage resources like images, documents, and other files.
+  * <<Connector>>: A servlet to manage resources like images, documents, and other
+    files.
   
   []
Index: FCKeditor.Java/trunk/src/site/apt/properties.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/properties.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/properties.apt	(revision 2151)
@@ -32,30 +32,31 @@
     <<<WEB-INF/classes>>>):
 
-+-------------------------------------------------------+
++------------------------------------------------------------------------------+
   ...
-  fckeditor.toolbarSet=Silver
+  fckeditor.toolbarSet=Basic
   connector.userActionImpl=net.fckeditor.requestcycle.impl.UserActionImpl
   ...
-+-------------------------------------------------------+
++------------------------------------------------------------------------------+
 
   * By calling dynamically the <<<PropertiesHolder>>> class:
 
-+-------------------------------------------------------+
++------------------------------------------------------------------------------+
   ...
   import net.fckeditor.handlers.PropertiesLoader;
   ...
-  PropertiesLoader.setProperty("fckeditor.toolbarSet", "Silver");
+  PropertiesLoader.setProperty("fckeditor.toolbarSet", "Basic");
   PropertiesLoader.setProperty("connector.userActionImpl", 
                    "net.fckeditor.requestcycle.impl.UserActionImpl");
   ...
-+-------------------------------------------------------+   
++------------------------------------------------------------------------------+
 
-    [Attention:] It is essential to know how to use the <<<PropertiesHolder>>>. Like 
-                 the common properties usage, you should use it only at 
-                 the start of your web application. If you don't have a kind of 
+    [Attention:] It is essential to know how to use the <<<PropertiesHolder>>>.
+                 Like the common properties usage, you should use it only at the
+                 start of your web application. If you don't have a kind of 
                  an 'initialization' servlet, where you could place the 
-                 PropertiesLoader calls, we suggest you to write your own 
-                 ServletContextListener. So you guarantee, you call the 
-                 PropertiesLoader <before> the ConnectorServlet is initialized.
+                 <<<PropertiesLoader>>> calls, we suggest you to write your own 
+                 <<<ServletContextListener>>>. So you guarantee, you call the 
+                 <<<PropertiesLoader>>> <before> the <<<ConnectorServlet>>> is
+                 initialized.
 
   []
@@ -88,6 +89,7 @@
   "media".
 
-  Define <<either>> an allowed <<or>> denied list. If an allowed list is pre-defined
-  overwrite it with an empty list and define your denied list as you wish.
+  Define <<either>> an allowed <<or>> denied list. If an allowed list is 
+  pre-defined overwrite it with an empty list and define your denied list as you
+  wish.
 
 *-------------------------------+--------------------------------+-----------------------------+----------------------------------------------------+
@@ -128,5 +130,5 @@
 *-------------------------------+--------------------------------+-----------------------------+----------------------------------------------------+
 | connector.fullUrl      		| false                          | true, false (boolean)	   | Indicates whether the server url will be prepended.|
-|								|								 |							   | I.e. prepending http://www.yourdomain.com/			|
+|								|								 |							   | I.e. prepending http://www.yourdomain.com			|
 *-------------------------------+--------------------------------+-----------------------------+----------------------------------------------------+
 | connector.secureImageUploads	|true							 | true, false (boolean)	   | Checks uploaded images for validity.				|
@@ -135,9 +137,9 @@
 *-------------------------------+--------------------------------+-----------------------------+----------------------------------------------------+
 | connector.userActionImpl		|								 | any class implementing the  | Provides custom security functions for the File	|
-|								|								 | {{{java-core/apidocs/net/fckeditor/requestcycle/UserAction.html}<<<net.fckeditor.requestcycle.UserAction>>>}} | Browser Connector. For more details see		|
+|								|								 | {{{java-core/apidocs/net/fckeditor/requestcycle/UserAction.html}<<<UserAction>>>}} | Browser Connector. For more details see		|
 |								|								 | interface			   | {{{connector.html}here}}. |
 *-------------------------------+--------------------------------+-----------------------------+----------------------------------------------------+
-| connector.userPathBuilderImpl |								 | any class implementing the  | Provides a custom function to construct a user-dependent 'UserFilesPath' for the |
-|								|								 | {{{java-core/apidocs/net/fckeditor/requestcycle/UserPathBuilder.html}<<<net.fckeditor.requestcycle.UserPathBuilder>>>}} | File Browser Connector. For more details see		|
+| connector.userPathBuilderImpl |								 | any class implementing the  | Provides a custom function to construct a user-dependent <<<UserFilesPath>>> for the |
+|								|								 | {{{java-core/apidocs/net/fckeditor/requestcycle/UserPathBuilder.html}<<<UserPathBuilder>>>}} | File Browser Connector. For more details see		|
 |								|								 | interface			   | {{{connector.html}here}}. |
 *-------------------------------+--------------------------------+-----------------------------+----------------------------------------------------+
Index: FCKeditor.Java/trunk/src/site/apt/taglibrary.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/taglibrary.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/taglibrary.apt	(revision 2151)
@@ -26,20 +26,20 @@
   Declare the tag extension in each JSP page that uses the FCKeditor.Java taglib.
   The uri directive must match the uri defined in the {{{java-core/tagreference.html}tag reference}}.
-  The prefix identifies the tags in the tag library within the JSP page.
+  The prefix identifies the tags in the tag library within a JSP page.
 
-+--------------------------------------------------------------------+
++------------------------------------------------------------------------------+
   <%@ taglib uri="http://java.fckeditor.net" prefix="FCK" %>
-+--------------------------------------------------------------------+
++------------------------------------------------------------------------------+
 
   The declaration, if you are using a JSP XML syntax, looks like:
 
-+--------------------------------------------------------------------+
++------------------------------------------------------------------------------+
   <jsp:root version="2.0" xmlns:jsp="http://java.sun.com/JSP/Page"
      xmlns:FCK="http://java.fckeditor.net">
-+--------------------------------------------------------------------+
++------------------------------------------------------------------------------+
 
   Now you are set to use the taglib. A brief declaration would be:
 
-+--------------------------------------------------------------------+
++------------------------------------------------------------------------------+
   <FCK:editor instanceName="EditorDefault">
     <jsp:attribute name="value">This is some <strong>sample text</strong>.
@@ -47,5 +47,5 @@
     </jsp:attribute>
   </FCK:editor>
-+--------------------------------------------------------------------+
++------------------------------------------------------------------------------+
 
   For a more complete overview, take a look at the {{{java-core/tagreference.html}tag reference}}.
Index: FCKeditor.Java/trunk/src/site/apt/velocity_freemarker.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/velocity_freemarker.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/velocity_freemarker.apt	(revision 2151)
@@ -22,40 +22,45 @@
                         ------------------------------
                         
-Integration with Velocity or Freemarker
+Integration with Velocity or FreeMarker
 
-  {{{http://velocity.apache.org}Velocity}} and {{{http://freemarker.org}Freemarker}} are quite similar and serve
-  similar needs and so are considered together in this section.
+  {{{http://velocity.apache.org}Velocity}} and {{{http://freemarker.org}FreeMarker}}
+  are quite similar and serve similar needs, they are discussed together in this
+  section.
 
-	[Hint:] This part of the documentation is just for people who are familiar with Velocity or Freemarker. It's
-	        just a hint for the right approach, how to use the Java Integration Pack with these template engines!
+    [Hint:] This part of the documentation is just for people who are familiar
+            with Velocity or FreeMarker. It's just a hint for an approach how to
+            use the Java Integration Pack with these template engines!
 
-  The required jars are <<<<velocity-1.x.x.jar>>> or <<<freemarker-2.x.jar>>> in order to work with 
-  Velocity or FreeMarker respectively and <<<commons-collections.jar>>> needs also to be available for Velocity. 
-  Drop the required jar files in your classpath (usually <<<WEB-INF/lib>>>).
+  The required jars are <<<velocity-1.x.x.jar>>> or <<<freemarker-2.x.jar>>> in 
+  order to work with Velocity or FreeMarker respectively and <<<commons-collections.jar>>>
+  has also to be available for Velocity. Drop the required jar files in your classpath
+  (usually <<<WEB-INF/lib>>>).
   
   The main class that builds the html for the editor is {{{java-core/apidocs/net/fckeditor/fckeditor.html}<<<net.fckeditor.FCKeditor>>>}}.
   We propose to write a wrapper object to initialize the FCKeditor object.\
-  Very simple example:
+  A very simple example:
   
-+----------------------------------------------------------------------------------+
++------------------------------------------------------------------------------+
 public class FCKeditorWrapper {
-	private HttpServletRequest httpServletRequest;
+  private HttpServletRequest request;
 
-	public FCKeditorWrapper(final HttpServletRequest httpServletRequest) {
-		this.httpServletRequest = httpServletRequest;
-	}
+  public FCKeditorWrapper(final HttpServletRequest request) {
+    this.request = request;
+  }
 
-	public String get(final String instanceName, final String value) {
-		FCKeditor editor = new FCKeditor(httpServletRequest, instanceName);
-		editor.setValue(value);
-		// HERE you could set other properties like 'fckconfig.js' 'fckstyles.xml' and so on.
-		return editor.create();
-	}
-+----------------------------------------------------------------------------------+
+  public String get(final String instanceName, final String value) {
+    FCKeditor editor = new FCKeditor(request, instanceName);
+    editor.setValue(value);
+    // HERE you could set other properties like 'fckconfig.js' 'fckstyles.xml' 
+    // and so on.
+    return editor.createHtml();
+  }
+}
++------------------------------------------------------------------------------+
 
-  Let's assume that you add <<<FCKeditorWrapper>>> with the name 'editor' to your context objects, then you just need the following minimal template
-  example (Velocity):
-  
-+----------------------------------------------------------------------------------+		
+  Let's assume that you add a <<<FCKeditorWrapper>>> instance to your context
+  objects, then you just need the following minimal template example (Velocity):
+
++------------------------------------------------------------------------------+
 <script language="javascript" type="text/javascript" src="/fckeditor/fckeditor.js"></script>
 <form method="post" action="[servlet path]">
@@ -63,3 +68,15 @@
    <input type="submit" value="OK" />
 </form>
-+----------------------------------------------------------------------------------+
+<<<<<<< .mine
+<<<<<<< .mine
++------------------------------------------------------------------------------+
+=======
++------------------------------------------------------------------------------+
+>>>>>>> .theirs
+=======
++------------------------------------------------------------------------------+
+
+
+
+
+>>>>>>> .theirs
Index: FCKeditor.Java/trunk/src/site/apt/whatsnew.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/whatsnew.apt	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/apt/whatsnew.apt	(revision 2151)
@@ -52,5 +52,6 @@
     * No configuration settings in the <<<web.xml>>> anymore.
 
-    * The configuration properties can be set in a common properties file or programmatically.
+    * The configuration properties can be set in a common properties file or 
+      programmatically.
 
     * 'Convention over conversion', just reset the properties which don't meet your
@@ -59,6 +60,6 @@
   * Introduced the state-of-the-art {{{http://www.slf4j.org}SLF4J}} logging facade.
 
-  * Pluggable interfaces have been introduced to extend the ConnectorServlet. This system
-    provides session or request-based functionality.
+  * Pluggable interfaces have been introduced to extend the ConnectorServlet. This
+    system provides session or request-based functionality.
 
   * JUnit test coverage on viable classes.
Index: FCKeditor.Java/trunk/src/site/site.xml
===================================================================
--- FCKeditor.Java/trunk/src/site/site.xml	(revision 2146)
+++ FCKeditor.Java/trunk/src/site/site.xml	(revision 2151)
@@ -29,5 +29,5 @@
 			/>
 			<item name="Connector" href="/connector.html" />
-			<item name="Velocity / Freemarker" href="/velocity_freemarker.html"/>
+			<item name="Velocity/FreeMarker" href="/velocity_freemarker.html"/>
 		</menu>
 		<menu name="Reference">

Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/CommandHandler.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/CommandHandler.java	(revision 2146)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/CommandHandler.java	(revision 2151)
@@ -23,4 +23,6 @@
 import java.util.HashMap;
 import java.util.Map;
+
+import net.fckeditor.tool.Utils;
 
 /**
@@ -74,8 +76,8 @@
 	 *         the string argument.
 	 * @throws IllegalArgumentException
 	 *             If 'name' is <code>null</code> or does not exist.
 	 */
 	public static CommandHandler valueOf(final String name) throws IllegalArgumentException {
-		if (name == null)
+		if (Utils.isEmpty(name))
 			throw new IllegalArgumentException();
 
@@ -74,8 +76,8 @@
 	 *         the string argument.
 	 * @throws IllegalArgumentException
-	 *             If 'name' is <code>null</code> or does not exist.
+	 *             If 'name' is <code>null</code>, empty, or does not exist.
 	 */
 	public static CommandHandler valueOf(final String name) throws IllegalArgumentException {